import { ElementType, HTMLAttributes } from 'react';
import { PolymorphicRefForwardingComponent } from '../../helpers';
import type { Colors } from '../../types';
export interface CNavbarProps extends HTMLAttributes<HTMLDivElement> {
    /**
     * Component used for the root node. Either a string to use a HTML element or a component.
     */
    as?: ElementType;
    /**
     * A string of all className you want applied to the component.
     */
    className?: string;
    /**
     * Sets the color context of the component to one of CoreUI’s themed colors.
     *
     * @type 'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'dark' | 'light' | string
     */
    color?: Colors;
    /**
     * Sets if the color of text should be colored for a light or dark background.
     */
    colorScheme?: 'dark' | 'light';
    /**
     * Defines optional container wrapping children elements.
     */
    container?: boolean | 'sm' | 'md' | 'lg' | 'xl' | 'xxl' | 'fluid';
    /**
     * Defines the responsive breakpoint to determine when content collapses.
     */
    expand?: boolean | 'sm' | 'md' | 'lg' | 'xl' | 'xxl';
    /**
     * Place component in non-static positions.
     */
    placement?: 'fixed-top' | 'fixed-bottom' | 'sticky-top';
}
export declare const CNavbar: PolymorphicRefForwardingComponent<'nav', CNavbarProps>;
